@@ -74,7 +74,7 @@ def main(in_path, out_path):
 
     else:
         if os.path.isdir(out_path):
-            out_path = os.path.join(output_path, os.path.splitext(os.path.basename(in_path))[0] + ".png"
+            out_path = os.path.join(output_path, os.path.splitext(os.path.basename(in_path))[0]) + ".png"
         w(
             out_path,
             parsing_face(
